@@ -1,5 +1,5 @@
 import re
-import urllib
+from urllib2 import urlopen
 from .feed import Feed
 
 class StatusPage(object):
@@ -15,6 +15,7 @@ class StatusPage(object):
 
     def __init__(self):
         self.page_source = None
+        self.feeds = set()
         self.rss_urls = set()
         self.services = set()
         self.regions = set()
@@ -22,7 +23,7 @@ class StatusPage(object):
 
     def page(self):
         if not self.page_source:
-            self.page_source = urllib.urlopen(self.BASE_URL)
+            self.page_source = urlopen(self.BASE_URL)
         return self.page_source
 
     def parse_page(self):
@@ -30,6 +31,7 @@ class StatusPage(object):
         for match in re.finditer(self.RSS_RE, page_content):
             absolute_url = self.BASE_URL + match.group('feed_url')
             feed = Feed(absolute_url)
+            self.feeds.add(feed)
             self.rss_urls.add(feed.url)
             if feed.service:
                 self.services.add(feed.service)
